# This model is published on: Teunis, P. F., Marinović, A. B., Tribble, D. R., Porter, C. K., & Swart, A. (2018). Acute illness from Campylobacter jejuni may require high doses while infection occurs at low doses. Epidemics, 24, 1-20.
# Please, when applying the model, make reference to the paper above.

library('reshape2')
library('ggplot2')

runDR<- data.frame('Qillmean'=c(Qillmean), 'Qinfmean'=c(Qinfmean))
runDR.melt <- melt(as.data.frame(runDR[c('Qillmean', 'Qinfmean')]), variable.name = 'Prob', value.name = 'Prob.value')

# plot(runDR)

if(all(dose == dose[1])){
  text.sim.dose <- paste('A dose of ', dose[1], ' CFU is considered.', sep='')
}else{
  text.sim.dose <- paste('For each simulation, ', length(dose), ' doses are presented.', sep='')
}
text.sim <- paste('Uncertainty (median, 25 % and 75 % quantile;\n whiskers are the maximum and minimum of the distribution;\n dots are extreme values)\n of the probability of illness and infection over ', n_sim, ' simulations. ', sep='')

text.ggplot <- paste(text.sim, text.sim.dose, sep='\n')

ggplot(runDR.melt, aes(Prob, Prob.value*100))+
  geom_boxplot()+
  xlab(label = '')+#'Probability of'
  ylab('Probability [%]') +
  scale_x_discrete(label=c('Illness', 'Infection'))+
  labs(caption=text.ggplot)+
  theme(text = element_text(size = 16),
        legend.text = element_text(size = 12))								
